summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorBo Yang <struggleyb.nku@gmail.com>2009-03-20 13:42:31 +0000
committerBo Yang <struggleyb.nku@gmail.com>2009-03-20 13:42:31 +0000
commit7dc9fcdd288b42c1122d957bc361153b5618b0e0 (patch)
treefb630d249edd9affb853d78a45ef9cde545fce96 /src
parent51683f2262fd165f477edebb934ffe9065bf3fff (diff)
downloadlibdom-7dc9fcdd288b42c1122d957bc361153b5618b0e0.tar.gz
libdom-7dc9fcdd288b42c1122d957bc361153b5618b0e0.tar.bz2
Fix the spelling initialize -> initialise.
svn path=/trunk/dom/; revision=6809
Diffstat (limited to 'src')
-rw-r--r--src/core/attr.c2
-rw-r--r--src/core/document.c2
-rw-r--r--src/core/document_type.c2
-rw-r--r--src/core/element.c6
-rw-r--r--src/core/element.h2
5 files changed, 7 insertions, 7 deletions
diff --git a/src/core/attr.c b/src/core/attr.c
index 5cb00ad..9fbb06f 100644
--- a/src/core/attr.c
+++ b/src/core/attr.c
@@ -73,7 +73,7 @@ dom_exception dom_attr_create(struct dom_document *doc,
if (a == NULL)
return DOM_NO_MEM_ERR;
- /* Initialize the vtable */
+ /* Initialise the vtable */
a->base.base.vtable = &attr_vtable;
a->base.destroy = _dom_attr_destroy;
diff --git a/src/core/document.c b/src/core/document.c
index 0f96908..8cfcfd0 100644
--- a/src/core/document.c
+++ b/src/core/document.c
@@ -159,7 +159,7 @@ dom_exception dom_document_create(struct dom_implementation *impl,
d->alloc = alloc;
d->pw = pw;
- /* Initialize the virtual table */
+ /* Initialise the virtual table */
d->base.base.vtable = &document_vtable;
d->base.destroy = &dom_document_destroy;
diff --git a/src/core/document_type.c b/src/core/document_type.c
index c5660bc..fc1a1e9 100644
--- a/src/core/document_type.c
+++ b/src/core/document_type.c
@@ -70,7 +70,7 @@ dom_exception dom_document_type_create(struct dom_string *qname,
return err;
}
- /* Initialize the vtable */
+ /* Initialise the vtable */
result->base.base.vtable = &document_type_vtable;
result->base.destroy = &dom_document_type_destroy;
diff --git a/src/core/element.h b/src/core/element.h
index 7a674e3..5b3d26c 100644
--- a/src/core/element.h
+++ b/src/core/element.h
@@ -35,7 +35,7 @@ dom_exception dom_element_create(struct dom_document *doc,
struct dom_string *name, struct dom_string *namespace,
struct dom_string *prefix, struct dom_element **result);
-dom_exception dom_element_initialize(struct dom_element *el,
+dom_exception dom_element_initialise(struct dom_element *el,
struct dom_string *name, struct dom_string *namespace,
struct dom_string *prefix, struct dom_element **result);
diff --git a/src/core/element.c b/src/core/element.c
index 01a61ba..98feb18 100644
--- a/src/core/element.c
+++ b/src/core/element.c
@@ -27,7 +27,7 @@ static struct dom_element_vtable element_vtable = {
};
/**
* Initialize an element node
*
* \param doc The owning document
* \param name The (local) name of the node to create
@@ -43,7 +43,7 @@ static struct dom_element_vtable element_vtable = {
*
* The returned element will already be referenced.
*/
-dom_exception dom_element_initialize(struct dom_element *el,
+dom_exception dom_element_initialise(struct dom_element *el,
struct dom_string *name, struct dom_string *namespace,
struct dom_string *prefix, struct dom_element **result)
{
@@ -103,7 +103,7 @@ dom_exception dom_element_create(struct dom_document *doc,
if (el == NULL)
return DOM_NO_MEM_ERR;
- dom_element_initialize(el, name, namespace, prefix, result);
+ dom_element_initialise(el, name, namespace, prefix, result);
return DOM_NO_ERR;
}
@@ -27,7 +27,7 @@ static struct dom_element_vtable element_vtable = {
};
/**
- * Initialize an element node
+ * Initialise an element node
*
* \param doc The owning document